{% extends "base.html" %}
{% block title %}settings - özgürsözlük{% endblock %}
{% block meta %}
    <meta name="title" content="settings - özgürsözlük">
    <meta name="description" content="{{ description }}">
{% endblock %}
{% block main %}
    <div class="settings">
        <form method="POST" action="/settings">
            <div class="settings-group">
                theme:
                <select name="theme">
                    {% for theme in themes %}
                        <option value="{{ theme }}"
                            {% if default_theme == theme %}selected{% endif %}>
                            {{ theme }}
                        </option>
                    {% endfor %}
                </select>
            </div>
            <div class="settings-group">
                display pinned topics:
                <select name="display_pinned_topics">
                    {% for status in ['true', 'false'] %}
                        <option value="{{ status }}"
                            {% if default_display_pinned_topics == status %}selected{% endif %}>
                            {{ status }}
                        </option>
                    {% endfor %}
                </select>
            </div>
            <div class="settings-group">
                display entry favorite count:
                <select name="display_entry_favorite_count">
                    {% for status in ['true', 'false'] %}
                        <option value="{{ status }}"
                            {% if  default_display_entry_favorite_count == status %}selected{% endif %}>
                            {{ status }}
                        </option>
                    {% endfor %}
                </select>
            </div>
            <div class="settings-group">
                display entry author:
                <select name="display_entry_author">
                    {% for status in ['true', 'false'] %}
                        <option value="{{ status }}"
                            {% if  default_display_entry_author == status %}selected{% endif %}>
                            {{ status }}
                        </option>
                    {% endfor %}
                </select>
            </div>
            <div class="settings-group">
                display entry datetime:
                <select name="display_entry_datetime">
                    {% for status in ['true', 'false'] %}
                        <option value="{{ status }}"
                            {% if  default_display_entry_datetime == status %}selected{% endif %}>
                            {{ status }}
                        </option>
                    {% endfor %}
                </select>
            </div>
            <div style="text-align: right; padding-top: 2rem; padding-bottom: 2rem;">
                <button style="width: 100%;" type="submit">save</button>
            </div>
        </form>
        <div style="text-align: center;">
            note: settings are saved in browser cookies, clearing your cookies will reset them.
            also this website does not have an official affiliation with eksisozluk.com.
            </br></br>
            v{{ version }}
            -
            last commit:
            <a href="{{ source_code }}/commit/{{ last_commit }}" target="_blank">{{ last_commit[:8] }}</a>
            -
            made with <3 on the <a href="{{ url_for('topic', path='thinkpad-t61--1883047') }}">t61</a>
            </br></br>
            contributors:
            {% for contributor in contributors %}
                <a href="https://github.com/{{ contributor['username'] }}">{{ contributor['username'] }}</a>
                ({{ contributor['total-commit'] }})
            {% endfor %}
        </div>
    </div>
{% endblock %}
