<div class="searchbox">
    <form method="POST" action="/">
        <input type="text" placeholder="search topic... e.g: atatürk" name="q">
        <button type="submit">fetch</button>
    </form>
</div>
