{% extends "base.html" %}
{% block title %}search - özgürsözlük{% endblock %}
{% block meta %}
    <meta name="title" content="search - özgürsözlük">
    <meta name="description" content="{{ q }}">
{% endblock %}
{% block main %}
    <nav>{% include "navigation.html" %}</nav>
    <div class="topic">
        <div class="info">
            <div><p>search result: {{ q }}</p></div>
            <div></div>
        </div>
        {% for topic in search_result %}
            <a href="{{ url_for('topic', path=topic.path) }}" class="entry">
                <div style="display: flex; justify-content: space-between;">
                    <div>{{ topic.title }}</div>
                    <div>
                        {% if topic.entry_count %}
                            <small style="opacity: 0.5;">{{ topic.entry_count }}</small>
                        {% endif %}
                    </div>
                </div>
            </a>
        {% endfor %}
    </div>
{% endblock %}
